# OzNetNerd Cloud App Security

Convenience Python module for interacting with Trend Micro Cloud App Security (CAS)

## Installation

```
pip3 install onncas
```

## Environment Variables

* `CAS_URL`: Default is `	
api.tmcas.trendmicro.com` [(see options)](http://docs.trendmicro.com/en-us/enterprise/cloud-app-security-integration-api-online-help/getting-started-with/understanding-the-ur.aspx)
* `CAS_KEY`: CAS API key

## Examples

Example [code snippets](examples/).

# Contact

* Blog: oznetnerd.com
* Email: will@oznetnerd.com